@@ -54,9 +54,12 @@
     Updated by      Richard Gooch   3-OCT-1997: Configuration file now opened
   externally.
 
-    Last updated by Richard Gooch   5-OCT-1997: Added support for "ALIAS"
+    Updated by      Richard Gooch   5-OCT-1997: Added support for "ALIAS"
   directive.
 
+    Last updated by Richard Gooch   9-OCT-1997: Made use of new function
+  <st_expr_expand>.
+
 
 */
 #include <stdio.h>
@@ -72,8 +75,6 @@
 /*  Private functions  */
 STATIC_FUNCTION (void log_address, (CONST char *address, char *line,
 				    FILE *debug_fp) );
-STATIC_FUNCTION (void translate_filename,
-		 (char pathname[STRING_LENGTH], CONST char *name) );
 STATIC_FUNCTION (flag process_alias_line,
 		 (CONST char *recipient, CONST char *alias, FILE *config_fp,
 		  option_type *options, FILE *debug_fp,
@@ -364,7 +365,7 @@ static void log_address (CONST char *address, char *line, FILE *debug_fp)
 	/*  Find end of filename  */
 	for (ptr = line; !isspace (*ptr) && (*ptr != '\0'); ++ptr);
 	if (*ptr != '\0') *ptr++ = '\0';
-	translate_filename (filename, line);
+	st_expr_expand (filename, STRING_LENGTH, line, debug_fp);
 	line = ptr;
 	strings[0] = address;
 	if ( !search_file (filename, strings, debug_fp, &found) )
@@ -376,7 +377,7 @@ static void log_address (CONST char *address, char *line, FILE *debug_fp)
 	}
 	if (found) return;
     }
-    translate_filename (filename, logfile);
+    st_expr_expand (filename, STRING_LENGTH, logfile, debug_fp);
     if (debug_fp != NULL)
 	fprintf (debug_fp, "Logging new email address: \"%s\"\n", address);
     if ( ( fd = open (filename, O_WRONLY | O_APPEND, 0) ) == -1 )
@@ -394,22 +395,6 @@ static void log_address (CONST char *address, char *line, FILE *debug_fp)
     close (fd);
 }   /*  End Function log_address  */
 
-static void translate_filename (char pathname[STRING_LENGTH], CONST char *name)
-/*  [SUMMARY] Translate and copy a filename.
-    <pathname> The translated pathname is written here.
-    <name> The input filename.
-    [RETURNS] Nothing.
-*/
-{
-    if (strncmp (name, "~/", 2) == 0)
-    {
-	/*  Expand leading "~/"  */
-	strcpy ( pathname, getenv ("HOME") );
-	strcat (pathname, name + 1);
-    }
-    else strcpy (pathname, name);
-}   /*  End Function translate_filename  */
-
 static flag process_alias_line (CONST char *recipient, CONST char *alias,
 				FILE *config_fp, option_type *options,
 				FILE *debug_fp,stringlist_type *recipient_list)
