@@ -160,7 +160,10 @@
     Last updated by Richard Gooch   9-OCT-1997: Made use of new function
   <st_expr_expand>.
 
-    Last updated by Richard Gooch   21-OCT-1997: Conditionally include paths.h
+    Updated by      Richard Gooch   21-OCT-1997: Conditionally include paths.h
+
+    Last updated by Richard Gooch   27-OCT-1997: Fixed bug if no logfile
+  specified in configuration file.
 
 
 */
@@ -501,7 +504,7 @@ char *envp[];
 		      O_WRONLY | O_CREAT | O_APPEND, S_IRUSR | S_IWUSR) )
 	< 0 )
     {
-	fprintf (stderr, "Error opening file: \"%s\"\t%s\n", logfile,
+	fprintf (stderr, "Error opening logfile: \"%s\"\t%s\n", logfile,
 		 ERRSTRING);
 	myexit (RV_UNDEF_ERROR);
     }
@@ -1662,7 +1665,7 @@ flag check_mail;
     }
     if (logfile[0] == '\0')
     {
-	sprintf (txt, "%s/PGPdaemon.log.%s", pgppath, hostname);
+	sprintf (logfile, "%s/PGPdaemon.log.%s", pgppath, hostname);
     }
     else st_expr_expand (logfile, STRING_LENGTH, logfile, NULL);
 }   /*  End Function read_config  */
